@@ -1,6 +1,8 @@
 module Var : sig
   type t = string
   val compare : t -> t -> Ordering.t
+
+  module Set : Set.S with type elt = t
 end
 
 type t
@@ -9,6 +11,8 @@ module Map : Map.S with type key = Var.t
 
 val empty : t
 
+val vars : t -> Var.Set.t
+
 (** The environment when the process started *)
 val initial : t
 
@@ -22,6 +26,8 @@ val extend_env : t -> t -> t
 
 val add : t -> var:Var.t -> value:string -> t
 
+val remove : t -> var:Var.t -> t
+
 val diff : t -> t -> t
 
 val update : t -> var:string -> f:(string option -> string option) -> t
@@ -31,3 +37,5 @@ val to_sexp : t -> Sexp.t
 val of_string_map : string String.Map.t -> t
 
 val iter : t -> f:(string -> string -> unit) -> unit
+
+val pp : Format.formatter -> t -> unit
